# Golding Lab's NEURON Tools

A package of tools and files from the Golding Lab at UT Austin for compartmental modeling using the simulation software, [NEURON](https://www.neuron.yale.edu/neuron/).

## Features

- Pre-configured scripts for compartmental modeling.
- Neurolucida cell morphology upload
- Tools for generating, simulating and analyzing neuronal activity.
- User interfaces for Neuroscience Gateway and simulation generation
- Utilizes with the NEURON simulation environment.
- Developed and maintained by the Golding Lab.

## Getting Started

### Prerequisites

- Install [NEURON](https://www.neuron.yale.edu/neuron/download) on your system.
- Ensure Python 3.8+ is installed.


### Installation

Install using pip:
```bash
pip install golding_NEURON
```

and compile the NEURON mechanisms:
```bash
compile-mechs
```

*or*
----
Clone the repository:
```bash
git clone https://github.com/jaredcasarez/golding-NEURON.git
cd golding-NEURON
```
        
and compile the NEURON mechanisms:
```bash
python -m golding_NEURON.compile_mechs
```

## Resources

- [Golding Lab Website](https://goldinglab.org)
- [NEURON Documentation](https://www.neuron.yale.edu/neuron/)
- [GitHub Repository](https://github.com/jaredcasarez/golding-NEURON)

## Acknowledgments

This project is developed and maintained by the [Golding Lab](https://goldinglab.org) at UT Austin. Special thanks to all contributors and the NEURON development team.

## License

This project is licensed under the MIT License. See the LICENSE file for details.